==> mcg_extension-1.0.0.tar.gz: lib/get/app_controller.dart <==
import 'dart:async';
import 'dart:convert';

import 'package:cross_connectivity/cross_connectivity.dart' as c;
import 'package:flutter_cache_manager/flutter_cache_manager.dart';
import 'package:get/get.dart';
import 'package:hive_flutter/hive_flutter.dart';
import 'package:mcg_extension/devicemanager.dart';
import 'package:mcg_extension/preferences/secure_preferences.dart';

import '../design/mytheme.dart';
import '../extensions/stringextension.dart';
import '../meta.dart';
import '../preferences/mypreferences.dart';
import 'alert.dart';
import 'translate.dart';

class AppController extends GetxController {
  late Box webFileCacheBox;

  late MyPreferences preferences;
  late SecurePreferences securePreferences;

  ///[commonEncryptKey] Herhangi bir rasgele datayi sifrelemek icin
  /// kullanabilirsin. Mesela sinav pdfi. Yada SecurePreferences,
  /// Ornek kullanim file.byteData.decrypt(Get.appController.commonEncryptKey)
  /// Genel sifreleme icin [mapEncKey] ve [iVEncKey] yardimci olmakta.
  /// Hepsi 32 karakter olmali
  final String commonEncryptKey;
  final String mapEncKey;
  final String iVEncKey;
  AppController({required this.commonEncryptKey, required this.mapEncKey, required this.iVEncKey});

  late StreamSubscription _connecTionSubscription;
  bool _hasConnaction = false;
  late List<int> secureKey;

  bool hasConnection(bool warning) {
    if (!_hasConnaction && warning) Alert.alert(type: AlertType.danger, message: 'noconnection'.translate);
    return _hasConnaction;
  }

  Future<void> init({int securePreferencesBoxNo = 1, int webCacheBoxVersion = 1}) async {
    await Hive.initFlutter('mcg');

    preferences = MyPreferences();
    await preferences.init();
    _prepareSecureKey();
    securePreferences = SecurePreferences();

    await securePreferences.init(boxNo: securePreferencesBoxNo);

    webFileCacheBox = await Hive.openBox('cacheBox$webCacheBoxVersion');
  }

  @override
  void onInit() {
    super.onInit();

    _prepareConnection();
  }

  void _prepareConnection() {
    _connecTionSubscription = c.Connectivity().isConnected.listen((bool result) => _hasConnaction = result);
    c.Connectivity().checkConnection().then((value) => _hasConnaction = value);
  }

  @override
  void onClose() {
    super.onClose();
    _connecTionSubscription.cancel();
  }

  ///SeasonCacheBox
  Map<String, dynamic> seasonCacheBox = <String, dynamic>{};

  /// Dil dosyasi
  final Map<String, String> localizedValues = {};
  void localizeDataClear() => localizedValues..clear();
  void localizeDataAddAll(Map<String, String> values) => localizedValues..addAll(values);

  /// Tema dosyasi
  Design? design;
  void setDesign(Design design) => this.design = design;
  Design? secondaryDesign;
  void setSecondaryDesign(Design secondaryDesign) => this.secondaryDesign = secondaryDesign;

  @unModifiable
  static const secureKeyPreferencesPath = 'skfhb';

  void _prepareSecureKey() {
    var _securityKey = preferences.getString(secureKeyPreferencesPath);
    if (_securityKey == null) {
      var _hiveKey = Hive.generateSecureKey();
      preferences.setString(secureKeyPreferencesPath, base64UrlEncode(_hiveKey).mix!);
      _securityKey = base64UrlEncode(_hiveKey).mix;
    }
    secureKey = base64Url.decode(_securityKey.unMix!);
  }

  CacheManager photoCacheManager = CacheManager(
    Config(
      'photoCache2',
      stalePeriod: const Duration(days: 90),
      maxNrOfCacheObjects: 20000,
    ),
  );
  CacheManager videoCacheManager = CacheManager(
    Config(
      'videoCache2',
      stalePeriod: const Duration(days: 30),
      maxNrOfCacheObjects: 500,
    ),
  );
}

==> mcg_extension-1.0.1.tar.gz: lib/get/app_controller.dart <==
import 'dart:async';
import 'dart:convert';

import 'package:cross_connectivity/cross_connectivity.dart' as c;
import 'package:flutter_cache_manager/flutter_cache_manager.dart';
import 'package:get/get.dart';
import 'package:hive_flutter/hive_flutter.dart';

import '../design/mytheme.dart';
import '../enums.dart';
import '../extensions/stringextension.dart';
import '../meta.dart';
import '../over/over.dart';
import '../preferences/mypreferences.dart';
import '../preferences/secure_preferences.dart';
import 'translate.dart';

class AppController extends GetxController {
  //? Web icin butun resimler dosyalar mobile icin ise ozellikle atilanlar saklanir
  late Box fileCacheBox;

  late MyPreferences preferences;
  late SecurePreferences securePreferences;

  ///[commonEncryptKey] Herhangi bir rasgele datayi sifrelemek icin
  /// kullanabilirsin. Mesela sinav pdfi. Yada SecurePreferences,
  /// Ornek kullanim file.byteData.decrypt(Get.appController.commonEncryptKey)
  /// Genel sifreleme icin [mapEncKey] ve [iVEncKey] yardimci olmakta.
  /// Hepsi 32 karakter olmali
  final String commonEncryptKey;
  final String mapEncKey;
  final String iVEncKey;
  AppController({required this.commonEncryptKey, required this.mapEncKey, required this.iVEncKey});

  late StreamSubscription _connecTionSubscription;
  bool _hasConnaction = false;
  late List<int> secureKey;

  bool hasConnection(bool warning) {
    if (!_hasConnaction && warning) OverAlert.show(type: AlertType.danger, message: 'noconnection'.translate);
    return _hasConnaction;
  }

  Future<void> init({int securePreferencesBoxNo = 1, int fileCacheBoxVersion = 1}) async {
    await Hive.initFlutter('mcg');

    preferences = MyPreferences();
    await preferences.init();
    _prepareSecureKey();
    securePreferences = SecurePreferences();

    await securePreferences.init(boxNo: securePreferencesBoxNo);

    fileCacheBox = await Hive.openBox('cacheBox$fileCacheBoxVersion');
  }

  @override
  void onInit() {
    super.onInit();

    _prepareConnection();
  }

  void _prepareConnection() {
    _connecTionSubscription = c.Connectivity().isConnected.listen((bool result) {
      OverExtension.changeConnectionLostWidget(!result);
      _hasConnaction = result;
    });
    c.Connectivity().checkConnection().then((value) => _hasConnaction = value);
  }

  @override
  void onClose() {
    super.onClose();
    _connecTionSubscription.cancel();
  }

  ///SeasonCacheBox
  Map<String, dynamic> seasonCacheBox = <String, dynamic>{};

  /// Dil dosyasi
  final Map<String, String> localizedValues = {};
  void localizeDataClear() => localizedValues..clear();
  void localizeDataAddAll(Map<String, String> values) => localizedValues..addAll(values);

  /// Tema dosyasi
  Design? design;
  void setDesign(Design design) => this.design = design;
  Design? secondaryDesign;
  void setSecondaryDesign(Design secondaryDesign) => this.secondaryDesign = secondaryDesign;

  @unModifiable
  static const secureKeyPreferencesPath = 'skfhb';

  void _prepareSecureKey() {
    String? _securityKey = preferences.getString(secureKeyPreferencesPath);
    if (_securityKey == null) {
      var _hiveKey = Hive.generateSecureKey();
      preferences.setString(secureKeyPreferencesPath, base64UrlEncode(_hiveKey).mix!);
      _securityKey = base64UrlEncode(_hiveKey).mix;
    }
    secureKey = base64Url.decode(_securityKey.unMix!);
  }

  CacheManager photoCacheManager = CacheManager(
    Config(
      'photoCache2',
      stalePeriod: const Duration(days: 90),
      maxNrOfCacheObjects: 20000,
    ),
  );
  CacheManager videoCacheManager = CacheManager(
    Config(
      'videoCache2',
      stalePeriod: const Duration(days: 30),
      maxNrOfCacheObjects: 500,
    ),
  );
}
